/*
 * BitCtrl-Funktionsbibliothek
 * Copyright (C) 2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.interpreter.logik;

import com.bitctrl.i18n.Messages;

import de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterException;
import de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterMessages;

import java.util.*;

/**
 * Wertobjekt für einen booleschen Wert.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public final class LogischerWert {

	public static final LogischerWert WAHR = new LogischerWert(true);

	public static final LogischerWert FALSCH = new LogischerWert(false);

	public static final LogischerWert of(final boolean wert) {
		return wert ? WAHR : FALSCH;
	}

	private final boolean wert;

	private LogischerWert(boolean wert){
		this.wert = wert;
	}

	public boolean get() {
		return wert;
	}

	@Override
	public boolean equals(Object o) {
		if (this == o) return true;
		if (o == null || getClass() != o.getClass()) return false;
		LogischerWert that = (LogischerWert) o;
		return wert == that.wert;
	}

	@Override
	public int hashCode() {
		return Objects.hash(wert);
	}

	@Override
	public String toString() {
		return wert ? "wahr" : "falsch";
	}

}
